@@ -5,6 +5,7 @@ exposed in the :py:mod:`mlflow.tracking` module.
 """
 
 import time
+import typing
 import os
 
 from mlflow.store.tracking import SEARCH_MAX_RESULTS_DEFAULT
@@ -160,12 +161,12 @@ class TrackingServiceClient:
         """
         return self.store.get_experiment(experiment_id)
 
-    def get_experiment_by_name(self, name):
+    def get_experiment_by_name(self, name, owner_subject_id: typing.Optional[str] = None):
         """
         :param name: The experiment name.
         :return: :py:class:`mlflow.entities.Experiment`
         """
-        return self.store.get_experiment_by_name(name)
+        return self.store.get_experiment_by_name(name, owner_subject_id=owner_subject_id)
 
     def create_experiment(self, name, artifact_location=None, tags=None):
         """Create an experiment.
